# 貢獻者公約行為準則

## 我們的承諾

為了促進一個開放和友善的環境，我們作為專案的貢獻者和維護者，致力於確保每位成員享有良好的體驗和合作關係。無論是在專案的討論、貢獻、問題回報或任何其他互動中，我們都希望每個人都能感到受到尊重和歡迎。

## 我們的準則

請在參與專案的所有活動中遵守以下準則：

- 尊重和包容不同的觀點和經驗。
- 尊重其他人的隱私和個人空間。
- 依循專案的規範、流程和方針。
- 當提出或回報問題時，請提供清晰、有益的資訊，並以建設性的方式進行討論。
- 對其他人保持友好和耐心，以建立良好的溝通和合作關係。
- 避免使用冒犯性、侮辱性或歧視性的言論。
- 禁止騷擾、恐嚇和其他可以合理認定不恰當或有違職業道德的行為。

## 我們的責任

專案的維護者有責任確保行為準則的執行。

如果有任何不適當或不尊重的行為，維護者有權和責任採取適當的措施，包括移除與本行為準則有所違背的評論、提交、程式碼和其他貢獻，並暫時或永久禁止不適當行為的參與者。

## 適用範圍

本行為準則適用於所有在專案中參與貢獻或互動的人士，包括但不限於管理者、維護者和使用者。

## 執行準則

如果您遇到任何違反行為準則的情況，請透過組織內部信箱聯絡專案[管理者][mailto]，我們將儘快回應和處理您的案件。

我們保證：

- 所有投訴將會被公正地審查和調查。
- 保護任何事件當事人的隱私和安全。

[mailto]: mailto:nicscda@nics.nat.gov.tw?subject=Report%20Conduct%20Violation&body=👤%20檢舉人資訊%0A%20%20%20%20姓名%3A%20%20%20%20(先生/小姐)%0A%20%20%20%20所屬%3A%20%20%20%20(單位/組織)%0A%0A%0A💥%20事件經過（詳述發生過程、日期時間和具體地點）%0A%20%20%20%20%0A%0A👥%20涉及對象（如果知道請提供姓名）%0A%20%20%20%20%0A%0A🗃️%20佐證資料（包含文字、圖片或影音保存證據）%0A%20%20%20%20%0A%0A🚫%20違反事項（請參照7大準則並詳加說明）%0A%20%20%20%20%0A%0A

## 來源

本行為準則改編自 [貢獻者公約][homepage] 2.1 版，請參見
<https://contributor-covenant.org/version/2/1>

有關本行為準則的常見問答，請參閱
<https://contributor-covenant.org/faq>

其他語系翻譯請查閱
<https://contributor-covenant.org/translations>

[homepage]: https://contributor-covenant.org
